(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    303130,       9082]
NotebookOptionsPosition[    295130,       8956]
NotebookOutlinePosition[    295538,       8972]
CellTagsIndexPosition[    295495,       8969]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Polarization Sums for Massive Spin-1, Spin-2, and Spin-3 Particles\
\>", "Title",
 CellChangeTimes->{{3.82836552654208*^9, 3.828365533118307*^9}, {
  3.828365579753315*^9, 
  3.8283655939771748`*^9}},ExpressionUUID->"d1dd134f-0d78-4c9c-b581-\
c1d015c5b93d"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "We", " ", "want", " ", "to", " ", "derive", " ", "the", " ", 
       "polarization", " ", "sum", " ", "for", " ", "massive", " ", "spin"}], 
      "-", 
      RowBox[{
      "3", " ", "particles", " ", "given", " ", "in", " ", "the", " ", 
       "appendix", " ", "of"}]}], " ", "<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"1203.2501", ".", "pdf"}]}], ">", 
     RowBox[{
      RowBox[{".", " ", "For"}], " ", "completeness", " ", "and", " ", 
      "clarification"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "we", " ", "also", " ", "derive", " ", "the", " ", "polarization", " ", 
     "sums", " ", "of", " ", "massive", " ", "spin"}], "-", 
    RowBox[{"1", " ", "and", " ", "spin"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"particles", ".", " ", 
      RowBox[{"(", 
       RowBox[{
       "See", " ", "also", " ", "the", " ", "corresponding", " ", 
        "handwritten", " ", 
        RowBox[{"notes", "."}]}], ")"}]}]}]}]}], "  ", "*)"}]], "Input",
 CellChangeTimes->{{3.828365534402752*^9, 3.8283655439207897`*^9}, {
  3.828447433391724*^9, 
  3.828447451951582*^9}},ExpressionUUID->"4a797638-e151-4e1d-99e2-\
1f17aa270ff5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"1e38a4db-e71d-42a2-8f20-090887fbee0f"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (development version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (development version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.8284992045221*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"2199b663-28dd-4d60-874f-1133c76f2147"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.828499204534387*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"0ac933a5-cb85-4894-969c-4bc3bd9dcc3a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.828499204540215*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"11ca9796-05a2-4b76-9e47-c4f1abf0bf36"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.828499204545473*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"bf16bbf3-f896-46b9-bd76-c47c476f6519"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.828499204549301*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"8c7c50ca-58e0-4e1b-b975-3e52477d6c63"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828170647280959*^9, 3.828499204552157*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"f6229a3a-fae8-4dea-86a8-619b04561292"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"On", "-", 
     RowBox[{"shell", " ", "kinematics"}]}], ",", " ", 
    RowBox[{
     RowBox[{
     "since", " ", "polarization", " ", "vectors", " ", "imply", " ", "on"}], 
     "-", 
     RowBox[{"shell", " ", 
      RowBox[{"particles", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"SP", "[", "p", "]"}], "=", 
    SuperscriptBox["M", "2"]}], ";"}]}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"32736918-3162-4a93-9b91-7ee8371f6d14"],

Cell[CellGroupData[{

Cell["Spin-1", "Section",
 CellChangeTimes->{{3.8283549355514193`*^9, 
  3.8283549441605597`*^9}},ExpressionUUID->"c25e2ea8-de20-412f-b4c3-\
ab35b12aa7fb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "We", " ", "derive", " ", "the", " ", "polarization", " ", "sum", " ", 
     "for", " ", "massive", " ", "spin"}], "-", 
    RowBox[{
    "1", " ", "particles", " ", "with", " ", "the", " ", "following", " ", 
     "Lorentz"}], "-", 
    RowBox[{"covariant", " ", 
     RowBox[{"ansatz", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"P1Try", "[", 
      RowBox[{"\[Mu]_", ",", "\[Nu]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"A", 
       RowBox[{"(", 
        RowBox[{"MT", "[", 
         RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], ")"}]}], "+", 
      RowBox[{"B", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Mu]"}], "]"}], 
         RowBox[{"FV", "[", 
          RowBox[{"p", ",", "\[Nu]"}], "]"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Use", " ", "that", " ", 
      SubscriptBox["p", "\[Mu]"], 
      SuperscriptBox["\[Epsilon]", "\[Mu]"]}], "=", 
     RowBox[{
      RowBox[{
      "0", " ", "and", " ", "the", " ", "normalization", " ", "property", " ", 
       SubscriptBox["\[Epsilon]", "\[Mu]"], 
       RowBox[{"(", 
        RowBox[{"p", ",", "\[Lambda]"}], ")"}], 
       SuperscriptBox["\[Epsilon]", "\[Mu]"], 
       RowBox[{"(", 
        RowBox[{"p", ",", 
         RowBox[{"\[Lambda]", "'"}]}], ")"}]}], "=", 
      RowBox[{"-", 
       RowBox[{
        SubscriptBox["\[Delta]", 
         RowBox[{"\[Lambda]\[Lambda]", "'"}]], "."}]}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P1Try", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P1Try", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.828186955590679*^9, 3.8281870134493017`*^9}, {
  3.828187123764215*^9, 3.828187273727244*^9}, {3.8281876460090322`*^9, 
  3.828187653738616*^9}, {3.828355171706956*^9, 3.8283551734211187`*^9}, {
  3.828356218119629*^9, 3.82835621829563*^9}, {3.82835934466042*^9, 
  3.8283593450955887`*^9}, {3.828365686725093*^9, 3.8283656988241997`*^9}, {
  3.828500368937655*^9, 
  3.828500381872891*^9}},ExpressionUUID->"25479a54-80d5-4a2c-bb26-\
ee92d294c9b5"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SuperscriptBox[
    FormBox[
     OverscriptBox[
      FormBox["p",
       TraditionalForm], "_"],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]], " ", 
   RowBox[{"(", 
    RowBox[{"A", "+", 
     RowBox[{"B", " ", 
      SuperscriptBox["M", "2"]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.828187124247559*^9, 3.828187143653256*^9}, {
   3.8281871805236807`*^9, 3.828187215206212*^9}, 3.8281872765550127`*^9, 
   3.828355174256021*^9, 3.828359270887534*^9, 3.828359345652343*^9, 
   3.828499217657529*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"281bd23c-47a2-4cfd-90ea-0f7ceb2c530c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"4", " ", "A"}], "+", 
   RowBox[{"B", " ", 
    SuperscriptBox["M", "2"]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.828187124247559*^9, 3.828187143653256*^9}, {
   3.8281871805236807`*^9, 3.828187215206212*^9}, 3.8281872765550127`*^9, 
   3.828355174256021*^9, 3.828359270887534*^9, 3.828359345652343*^9, 
   3.828499217672373*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"8a531590-1230-4bb0-8dad-08476465eebb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Solve", " ", "for", " ", "the", " ", 
    RowBox[{"constants", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"A", "+", 
       RowBox[{"B", " ", 
        SuperscriptBox["M", "2"]}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"4", " ", "A"}], "+", 
       RowBox[{"B", " ", 
        SuperscriptBox["M", "2"]}]}], "\[Equal]", 
      RowBox[{"-", "3"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"A", ",", "B"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[7]:=",ExpressionUUID->"6fe1548c-870a-4a30-ad49-d055daceba75"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"B", "\[Rule]", 
      FractionBox["1", 
       SuperscriptBox["M", "2"]]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.828359346695487*^9, 3.8284992189117126`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"821049c6-2b29-4cb1-9b41-bed85b6f7f7a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "obtained", " ", "polarization", " ", "sum", " ", "for", " ", 
     "massive", " ", "spin"}], "-", 
    RowBox[{"1", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"MT", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "+", 
      FractionBox[
       RowBox[{
        RowBox[{"FV", "[", 
         RowBox[{"p", ",", "\[Alpha]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"p", ",", "\[Beta]"}], "]"}]}], 
       SuperscriptBox["M", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "The", " ", "only", " ", "alternatively", " ", "possible", " ", 
       "rank"}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"tensor", ".", " ", "Note"}], " ", "that", " ", "this", " ", 
       "structure", " ", "is", " ", "not", " ", "\"\<possible\>\"", " ", 
       "for", " ", "spin"}], "-", 
      RowBox[{"1", " ", "particles"}]}], ",", " ", 
     RowBox[{
     "see", " ", "above", " ", "and", " ", "the", " ", "properties", " ", 
      RowBox[{"below", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"X2", "[", 
      RowBox[{"\[Alpha]_", ",", "\[Beta]_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"MT", "[", 
        RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "-", 
      FractionBox[
       RowBox[{
        RowBox[{"FV", "[", 
         RowBox[{"p", ",", "\[Alpha]"}], "]"}], 
        RowBox[{"FV", "[", 
         RowBox[{"p", ",", "\[Beta]"}], "]"}]}], 
       SuperscriptBox["M", "2"]]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.828170623932784*^9, 3.8281706579382067`*^9}, 
   3.828170795051425*^9, {3.828171302502853*^9, 3.828171335492907*^9}, {
   3.828172129357912*^9, 3.8281721343729897`*^9}, {3.828172937686017*^9, 
   3.82817295881044*^9}, {3.828173028916523*^9, 3.82817302909731*^9}, {
   3.828173170267845*^9, 3.828173203165327*^9}, {3.828183091929343*^9, 
   3.828183101815475*^9}, {3.828183174517747*^9, 3.828183187718625*^9}, {
   3.8281832635265207`*^9, 3.828183282299367*^9}, {3.8281870177301407`*^9, 
   3.828187021765299*^9}, {3.8281872918852587`*^9, 3.828187328443932*^9}, {
   3.828355073651094*^9, 3.8283550758348093`*^9}, {3.828360295262164*^9, 
   3.828360297041523*^9}, {3.8283656406210403`*^9, 3.828365654755866*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"bf952724-57e9-48dc-9e5e-ff79b194e044"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "Properties", " ", "for", " ", "the", " ", "above", " ", "spin"}], "-", 
      
      RowBox[{"1", " ", "polarization", " ", 
       RowBox[{"sum", ":", " ", 
        RowBox[{
         SubscriptBox["p", "\[Mu]"], 
         SuperscriptBox["X", "\[Mu]\[Nu]"]}]}]}]}], "=", 
     RowBox[{
      RowBox[{"0", 
       RowBox[{"(", 
        RowBox[{"=", 
         RowBox[{
          SubscriptBox["p", "\[Nu]"], 
          SuperscriptBox["X", "\[Mu]\[Nu]"], " ", "but", " ", "symmetric", 
          " ", "anyway"}]}], ")"}], " ", "and", " ", 
       SubscriptBox["g", "\[Mu]\[Nu]"], 
       SuperscriptBox["X", "\[Mu]\[Nu]"]}], "=", 
      RowBox[{"-", "3"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"since", " ", "\[Epsilon]", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"p", ",", "\[Lambda]"}], ")"}], "\[Mu]"], "\[Epsilon]", 
      SubscriptBox[
       RowBox[{"(", 
        RowBox[{"p", ",", 
         RowBox[{"\[Lambda]", "'"}]}], ")"}], "\[Mu]"]}], "=", 
     RowBox[{"-", 
      RowBox[{
       SubscriptBox["\[Delta]", 
        RowBox[{"\[Lambda]\[Lambda]", "'"}]], "."}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"MT", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"X", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "And", " ", "for", " ", "the", " ", "alternatively", " ", "possible", 
      " ", "rank"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"tensor", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X2", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"FV", "[", 
      RowBox[{"p", ",", "\[Mu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X2", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"MT", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X2", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"X2", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "And", " ", "the", " ", "contraction", " ", "between", " ", "the", " ", 
     RowBox[{"two", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"X", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
     RowBox[{"X2", "[", 
      RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.8281727763027277`*^9, 3.828172853630584*^9}, {
  3.828172920299995*^9, 3.828172933048077*^9}, {3.828172981738758*^9, 
  3.828172994198008*^9}, {3.8281732062937393`*^9, 3.828173206940586*^9}, {
  3.828182928088788*^9, 3.82818307830678*^9}, {3.828183114383278*^9, 
  3.8281831145503798`*^9}, {3.828183668640283*^9, 3.82818367734435*^9}, {
  3.828187575106453*^9, 3.828187576939098*^9}, {3.828187708552829*^9, 
  3.8281877110362186`*^9}, {3.828499221893795*^9, 3.82849922259951*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"c3b7eedb-2e57-420b-90ff-49a7f358b92e"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.8284992232641478`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"e66f30cd-9dd8-4378-8953-635f2a206fb5"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "3"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223291545*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"19d6e099-43b6-4f98-854d-a86946c9d165"],

Cell[BoxData[
 FormBox["3", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223301559*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"f7ea0151-9161-4ae2-8110-4af482563ec2"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   SuperscriptBox[
    FormBox[
     OverscriptBox[
      FormBox["p",
       TraditionalForm], "_"],
     TraditionalForm], 
    FormBox[
     FormBox["\[Nu]",
      TraditionalForm],
     TraditionalForm]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223306636*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"17b9bc47-4a00-486c-b2cf-53720150166e"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", "5"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223311778*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"b5ddc06a-bd9e-46a1-81b2-8f8cae6a9ea5"],

Cell[BoxData[
 FormBox["7", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223320229*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"38cda6b5-bbfc-4fb3-984f-35c3ab5b2d55"],

Cell[BoxData[
 FormBox["3", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828172824673851*^9, 3.8281728709936037`*^9, 3.8281729208075867`*^9, {
   3.828172962903448*^9, 3.8281729953009233`*^9}, 3.828183116864592*^9, 
   3.8281875792590017`*^9, 3.828187711389453*^9, 3.828359288639436*^9, 
   3.828499223324328*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"00284538-ab6d-44b9-b3e9-79596db98281"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-2", "Section",
 CellChangeTimes->{{3.8283552765452147`*^9, 
  3.828355283625292*^9}},ExpressionUUID->"0de2768d-c289-47fd-bb45-\
216431be29fa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Ansatz", " ", "to", " ", "derive", " ", "the", " ", "polarization", " ", 
     "sum", " ", "for", " ", "a", " ", "massive", " ", "spin"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"particle", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P2Try", "[", 
     RowBox[{"\[Mu]1_", ",", "\[Mu]2_", ",", "\[Nu]1_", ",", "\[Nu]2_"}], 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"A1", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]2"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"A2", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
        RowBox[{"X", "[", 
         RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"A3", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]2"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"A4", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X2", "[", 
         RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
        RowBox[{"X2", "[", 
         RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"A5", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]2"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"A6", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
        RowBox[{"X2", "[", 
         RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], ")"}]}], "+", 
     RowBox[{"A7", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]2"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"A8", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X2", "[", 
         RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
        RowBox[{"X", "[", 
         RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], ")"}]}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.8281713216913757`*^9, 3.8281713454142227`*^9}, {
  3.8281715057230473`*^9, 3.828171706165937*^9}, {3.828172127628365*^9, 
  3.828172128331476*^9}, {3.828172429814992*^9, 3.8281725481969967`*^9}, {
  3.828173118150241*^9, 3.82817312601927*^9}, {3.828184008867879*^9, 
  3.828184011727394*^9}, {3.828187736970793*^9, 3.828187746396311*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"4f967f65-2973-45ff-b24b-9497872b6753"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "The", " ", "properties", " ", "of", " ", "the", " ", "above", " ", 
      "tensor", " ", "when", " ", "contracting", " ", "with", " ", "the", " ",
       "objects", " ", "as", " ", 
      RowBox[{"before", ".", " ", "One"}], " ", "additional", " ", 
      "constraints", " ", "reads", " ", 
      SuperscriptBox["g", "\[Mu]1\[Mu]2"], 
      SubsuperscriptBox["P", "\[Mu]1\[Mu]2", "\[Nu]1\[Nu]2"]}], "=", 
     RowBox[{"0", "=", 
      RowBox[{
       SubscriptBox["g", "\[Nu]1\[Nu]2"], 
       SubsuperscriptBox["P", "\[Mu]1\[Mu]2", "\[Nu]1\[Nu]2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Rule]", " ", 
           RowBox[{
            SuperscriptBox["g", "\[Mu]1\[Mu]2"], 
            SubscriptBox["g", "\[Nu]1\[Nu]2"], 
            SubsuperscriptBox["P", "\[Mu]1\[Mu]2", "\[Nu]1\[Nu]2"]}]}], "=", 
          "0"}], ",", " ", 
         RowBox[{"can", " ", "be", " ", "combined"}], ",", " ", 
         RowBox[{
         "no", " ", "difference", " ", "in", " ", "the", " ", "result"}], ",",
          " ", 
         RowBox[{"see", " ", "below"}]}], ")"}]}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"since", " ", "\[Epsilon]", 
      SubsuperscriptBox[
       RowBox[{"(", 
        RowBox[{"p", ",", "\[Lambda]"}], ")"}], "\[Mu]", "\[Mu]"]}], "=", 
     RowBox[{"0", " ", 
      RowBox[{
       RowBox[{"(", "traceless", ")"}], "."}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Mu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Nu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.828183444908024*^9, 3.828183449987208*^9}, {
   3.8281838096540213`*^9, 3.8281838279246817`*^9}, 3.828183875083213*^9, {
   3.828184029182776*^9, 3.828184033765267*^9}, {3.8281843110010433`*^9, 
   3.8281843401869173`*^9}, {3.8281844321571617`*^9, 3.82818443495111*^9}, {
   3.828187769466522*^9, 3.82818777334925*^9}, {3.8281878074532967`*^9, 
   3.828187811207334*^9}, {3.8281882696061687`*^9, 3.828188274576099*^9}, {
   3.828359229226307*^9, 3.82835924565272*^9}, {3.828359293564477*^9, 
   3.828359307386558*^9}, {3.828360460637457*^9, 3.828360472809744*^9}, {
   3.828360738052973*^9, 3.828360738554675*^9}, {3.828361405671208*^9, 
   3.8283614116400957`*^9}, {3.82841036855657*^9, 3.8284103692873983`*^9}, {
   3.828500257584396*^9, 3.828500257866592*^9}, {3.828500409070237*^9, 
   3.8285005204110727`*^9}, {3.828500588860919*^9, 
   3.828500614293792*^9}},ExpressionUUID->"869c43cd-eb24-48f7-9750-\
7219fb8789a1"],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["p",
           TraditionalForm], "_"],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]2",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["p",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]1",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["p",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]2",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A5", "-", "A7", "-", 
            "A8"}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["M", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"A4", "+", "A8"}], ")"}], " ", 
          SuperscriptBox[
           OverscriptBox["g", "_"], 
           RowBox[{
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]}]]}]}], ")"}]}], 
      SuperscriptBox["M", "2"]], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"A3", "+", "A5"}], ")"}], " ", 
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["p",
          TraditionalForm], "_"],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]2",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       OverscriptBox["g", "_"], 
       RowBox[{
        FormBox[
         FormBox["\[Mu]2",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]1",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"A3", "+", "A7"}], ")"}], " ", 
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["p",
          TraditionalForm], "_"],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]1",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       OverscriptBox["g", "_"], 
       RowBox[{
        FormBox[
         FormBox["\[Mu]2",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]2",
          TraditionalForm],
         TraditionalForm]}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.828500264120873*^9},
 CellLabel->"Out[59]=",ExpressionUUID->"fc9b2e55-26dc-45e8-ad70-690b631abaeb"],

Cell[BoxData[
 FormBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        FormBox[
         OverscriptBox[
          FormBox["p",
           TraditionalForm], "_"],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]1",
          TraditionalForm],
         TraditionalForm]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["p",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox[
            FormBox["\[Mu]2",
             TraditionalForm],
            TraditionalForm]], " ", 
          SuperscriptBox[
           FormBox[
            OverscriptBox[
             FormBox["p",
              TraditionalForm], "_"],
            TraditionalForm], 
           FormBox[
            FormBox["\[Nu]2",
             TraditionalForm],
            TraditionalForm]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A6", "-", 
            RowBox[{"2", " ", "A7"}]}], ")"}]}], "+", 
         RowBox[{
          SuperscriptBox["M", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"A3", "+", "A7"}], ")"}], " ", 
          SuperscriptBox[
           OverscriptBox["g", "_"], 
           RowBox[{
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]}]]}]}], ")"}]}], 
      SuperscriptBox["M", "2"]], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"A3", "+", "A7"}], ")"}], " ", 
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["p",
          TraditionalForm], "_"],
        TraditionalForm], 
       FormBox[
        FormBox["\[Mu]2",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       OverscriptBox["g", "_"], 
       RowBox[{
        FormBox[
         FormBox["\[Mu]1",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Nu]2",
          TraditionalForm],
         TraditionalForm]}]]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"A4", "+", "A6"}], ")"}], " ", 
      SuperscriptBox[
       FormBox[
        OverscriptBox[
         FormBox["p",
          TraditionalForm], "_"],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]2",
         TraditionalForm],
        TraditionalForm]], " ", 
      SuperscriptBox[
       OverscriptBox["g", "_"], 
       RowBox[{
        FormBox[
         FormBox["\[Mu]1",
          TraditionalForm],
         TraditionalForm], 
        FormBox[
         FormBox["\[Mu]2",
          TraditionalForm],
         TraditionalForm]}]]}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.8285002641845427`*^9},
 CellLabel->"Out[60]=",ExpressionUUID->"c3188ed6-0b62-478c-8164-2179e3cbec0c"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"12", " ", "A1"}], "+", 
   RowBox[{"3", " ", "A2"}], "+", 
   RowBox[{"32", " ", "A3"}], "+", 
   RowBox[{"7", " ", "A4"}], "+", 
   RowBox[{"18", " ", "A5"}], "+", 
   RowBox[{"3", " ", "A6"}], "+", 
   RowBox[{"18", " ", "A7"}], "+", 
   RowBox[{"3", " ", "A8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.828500264254838*^9},
 CellLabel->"Out[61]=",ExpressionUUID->"df36b9b7-adff-4843-a990-e32bdb95420f"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["g", "_"], 
     RowBox[{
      FormBox[
       FormBox["\[Nu]1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]2",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "A1"}], "+", 
      RowBox[{"3", " ", "A2"}], "+", 
      RowBox[{"2", " ", "A3"}], "+", 
      RowBox[{"5", " ", "A4"}], "+", 
      RowBox[{"2", " ", "A5"}], "+", 
      RowBox[{"3", " ", "A6"}], "+", 
      RowBox[{"2", " ", "A7"}], "+", 
      RowBox[{"5", " ", "A8"}]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]1",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]2",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "-", 
       RowBox[{"6", " ", "A3"}], "-", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "-", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "+", 
       RowBox[{"5", " ", "A8"}]}], ")"}]}], 
    SuperscriptBox["M", "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.8285002643236094`*^9},
 CellLabel->"Out[62]=",ExpressionUUID->"de0e3bce-5a62-4bac-96b5-bb7da98d8922"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SuperscriptBox[
     OverscriptBox["g", "_"], 
     RowBox[{
      FormBox[
       FormBox["\[Mu]1",
        TraditionalForm],
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]2",
        TraditionalForm],
       TraditionalForm]}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "A1"}], "+", 
      RowBox[{"3", " ", "A2"}], "+", 
      RowBox[{"2", " ", "A3"}], "+", 
      RowBox[{"5", " ", "A4"}], "+", 
      RowBox[{"2", " ", "A5"}], "+", 
      RowBox[{"5", " ", "A6"}], "+", 
      RowBox[{"2", " ", "A7"}], "+", 
      RowBox[{"3", " ", "A8"}]}], ")"}]}], "-", 
   FractionBox[
    RowBox[{
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]1",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]2",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "-", 
       RowBox[{"6", " ", "A3"}], "-", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "+", 
       RowBox[{"5", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "-", 
       RowBox[{"3", " ", "A8"}]}], ")"}]}], 
    SuperscriptBox["M", "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.828500264342606*^9},
 CellLabel->"Out[63]=",ExpressionUUID->"e322844a-72d2-4493-a9b0-6f390ed05f3d"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"6", " ", "A1"}], "+", 
   RowBox[{"9", " ", "A2"}], "+", 
   RowBox[{"14", " ", "A3"}], "+", 
   RowBox[{"25", " ", "A4"}], "+", 
   RowBox[{"6", " ", "A5"}], "+", 
   RowBox[{"15", " ", "A6"}], "+", 
   RowBox[{"6", " ", "A7"}], "+", 
   RowBox[{"15", " ", "A8"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.8281834508071213`*^9, 3.828183828390936*^9, 3.828183876879046*^9, {
   3.8281840192201233`*^9, 3.828184034371314*^9}, 3.828184340944392*^9, 
   3.828184435578433*^9, 3.828187773880665*^9, 3.828187814734456*^9, 
   3.828188275513246*^9, 3.8283604735118856`*^9, 3.828360738925066*^9, 
   3.8283614122925463`*^9, 3.8284103714609547`*^9, 3.828499544272118*^9, 
   3.8285002644083557`*^9},
 CellLabel->"Out[64]=",ExpressionUUID->"ab23a2ec-e90c-42ab-b379-974139529402"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solving", " ", "the", " ", "system", " ", "of", " ", "equations", " ", 
    "from", " ", "above", " ", "without", " ", "the", " ", "last", " ", 
    RowBox[{"constraint", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A5", "-", "A7", "-", "A8"}],
       "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A8"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A5"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A6", "-", 
       RowBox[{"2", " ", "A7"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A6"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"12", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "+", 
       RowBox[{"32", " ", "A3"}], "+", 
       RowBox[{"7", " ", "A4"}], "+", 
       RowBox[{"18", " ", "A5"}], "+", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"18", " ", "A7"}], "+", 
       RowBox[{"3", " ", "A8"}]}], "\[Equal]", 
      RowBox[{"-", "5"}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "+", 
       RowBox[{"2", " ", "A3"}], "+", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "+", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "+", 
       RowBox[{"5", " ", "A8"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "-", 
       RowBox[{"6", " ", "A3"}], "-", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "-", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "+", 
       RowBox[{"5", " ", "A8"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "+", 
       RowBox[{"2", " ", "A3"}], "+", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "+", 
       RowBox[{"5", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "+", 
       RowBox[{"3", " ", "A8"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "-", 
       RowBox[{"6", " ", "A3"}], "-", 
       RowBox[{"5", " ", "A4"}], "+", 
       RowBox[{"2", " ", "A5"}], "+", 
       RowBox[{"5", " ", "A6"}], "+", 
       RowBox[{"2", " ", "A7"}], "-", 
       RowBox[{"3", " ", "A8"}]}], "\[Equal]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "A7", 
      ",", "A8"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828500273094392*^9, 3.8285003304556637`*^9}},
 CellLabel->"In[65]:=",ExpressionUUID->"4451aa56-da71-4220-af09-4980324f68a6"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "Solve","svars",
    "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
    65,4,21029053522522598765,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.828500331961788*^9},
 CellLabel->
  "During evaluation of \
In[65]:=",ExpressionUUID->"7a3afabe-92ea-413c-ba52-e4cce478c5b8"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "A1"}]}], "-", 
       FractionBox["2", "3"]}]}], ",", 
     RowBox[{"A3", "\[Rule]", 
      RowBox[{"A1", "+", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "A1"}]}], "-", "1"}]}], ",", 
     RowBox[{"A5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "A1"}], "-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A6", "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", "1"}]}], ",", 
     RowBox[{"A7", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "A1"}], "-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A8", "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", "1"}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.82850033199041*^9},
 CellLabel->"Out[65]=",ExpressionUUID->"2bf9a024-c2ea-4c96-ae0d-6bac44575ae3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Solving", " ", "the", " ", "system", " ", "of", " ", "equations", " ", 
     "from", " ", "above", " ", "without", " ", "the", " ", "third"}], "-", 
    " ", 
    RowBox[{"and", " ", "second"}], "-", 
    RowBox[{"last", " ", 
     RowBox[{"constraint", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A5", "-", "A7", "-", "A8"}],
       "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A8"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A5"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A6", "-", 
       RowBox[{"2", " ", "A7"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A6"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"12", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "+", 
       RowBox[{"32", " ", "A3"}], "+", 
       RowBox[{"7", " ", "A4"}], "+", 
       RowBox[{"18", " ", "A5"}], "+", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"18", " ", "A7"}], "+", 
       RowBox[{"3", " ", "A8"}]}], "\[Equal]", 
      RowBox[{"-", "5"}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"6", " ", "A1"}], "+", 
       RowBox[{"9", " ", "A2"}], "+", 
       RowBox[{"14", " ", "A3"}], "+", 
       RowBox[{"25", " ", "A4"}], "+", 
       RowBox[{"6", " ", "A5"}], "+", 
       RowBox[{"15", " ", "A6"}], "+", 
       RowBox[{"6", " ", "A7"}], "+", 
       RowBox[{"15", " ", "A8"}]}], "\[Equal]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "A7", 
      ",", "A8"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828183481789905*^9, 3.828183495967589*^9}, {
  3.828183834714753*^9, 3.828183848018777*^9}, {3.828184048991002*^9, 
  3.8281841171087217`*^9}, {3.82818441302876*^9, 3.828184572255981*^9}, {
  3.8281878206590137`*^9, 3.828187928203135*^9}, {3.8281882820174522`*^9, 
  3.828188285504923*^9}, {3.828359311175394*^9, 3.8283593375030937`*^9}, {
  3.828360480875127*^9, 3.828360483892288*^9}, {3.828360599935543*^9, 
  3.82836062400401*^9}, {3.828360692424754*^9, 3.828360693793692*^9}, {
  3.828500279152594*^9, 3.828500289885407*^9}},
 CellLabel->"In[66]:=",ExpressionUUID->"1ad7f87a-8fa1-475d-ad38-f39947d6b38b"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "Solve","svars",
    "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
    66,5,21029053522522598765,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.8283606245313663`*^9, 3.828360694421494*^9, 
  3.8284103814584827`*^9, 3.8284995483129673`*^9, 3.828500335415111*^9},
 CellLabel->
  "During evaluation of \
In[66]:=",ExpressionUUID->"dfb7f152-3f09-4b72-a107-dd32499ad33d"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A2", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "A1"}]}], "-", 
       FractionBox["2", "3"]}]}], ",", 
     RowBox[{"A3", "\[Rule]", 
      RowBox[{"A1", "+", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"2", " ", "A1"}]}], "-", "1"}]}], ",", 
     RowBox[{"A5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "A1"}], "-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A6", "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", "1"}]}], ",", 
     RowBox[{"A7", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "A1"}], "-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A8", "\[Rule]", 
      RowBox[{
       RowBox[{"2", " ", "A1"}], "+", "1"}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828183848806243*^9, {3.828184097467305*^9, 3.828184117650964*^9}, 
   3.8281845731569967`*^9, 3.8281879303739243`*^9, 3.828188286393778*^9, 
   3.828360484811504*^9, {3.828360601228888*^9, 3.828360624552663*^9}, 
   3.828360694449347*^9, 3.828410381680822*^9, 3.8284995483455067`*^9, 
   3.8285003354396133`*^9},
 CellLabel->"Out[66]=",ExpressionUUID->"051f8341-a782-41ea-8ab9-3bbf3e40dee2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Additional", " ", "normalization", " ", "constraint", " ", "for", " ", 
     "the", " ", "tensor", " ", "itself"}], ";", " ", 
    RowBox[{
    "does", " ", "not", " ", "impose", " ", "any", " ", "new", " ", 
     "constraints", " ", 
     RowBox[{"apparently", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Contract", "[", 
    RowBox[{
     RowBox[{"P2Try", "[", 
      RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
     
     RowBox[{"P2Try", "[", 
      RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], 
      "]"}]}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.8283607461540337`*^9, 3.828360756541683*^9}, {
  3.828503270645994*^9, 
  3.8285032789846888`*^9}},ExpressionUUID->"9d17d561-d522-4502-94ad-\
55081abd3a98"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"24", " ", 
    SuperscriptBox["A1", "2"]}], "+", 
   RowBox[{"12", " ", "A1", " ", 
    RowBox[{"(", 
     RowBox[{"A2", "+", 
      RowBox[{"4", " ", "A3"}], "+", "A4", "+", 
      RowBox[{"4", " ", "A5"}], "+", "A6", "+", 
      RowBox[{"4", " ", "A7"}], "+", "A8"}], ")"}]}], "+", 
   RowBox[{"9", " ", 
    SuperscriptBox["A2", "2"]}], "+", 
   RowBox[{"6", " ", "A2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", " ", "A3"}], "+", 
      RowBox[{"3", " ", "A4"}], "+", 
      RowBox[{"2", " ", "A5"}], "+", 
      RowBox[{"3", " ", "A6"}], "+", 
      RowBox[{"2", " ", "A7"}], "+", 
      RowBox[{"3", " ", "A8"}]}], ")"}]}], "+", 
   RowBox[{"136", " ", 
    SuperscriptBox["A3", "2"]}], "+", 
   RowBox[{"76", " ", "A3", " ", "A4"}], "+", 
   RowBox[{"96", " ", "A3", " ", "A5"}], "+", 
   RowBox[{"12", " ", "A3", " ", "A6"}], "+", 
   RowBox[{"96", " ", "A3", " ", "A7"}], "+", 
   RowBox[{"12", " ", "A3", " ", "A8"}], "+", 
   RowBox[{"49", " ", 
    SuperscriptBox["A4", "2"]}], "+", 
   RowBox[{"12", " ", "A4", " ", "A5"}], "+", 
   RowBox[{"42", " ", "A4", " ", "A6"}], "+", 
   RowBox[{"12", " ", "A4", " ", "A7"}], "+", 
   RowBox[{"42", " ", "A4", " ", "A8"}], "+", 
   RowBox[{"48", " ", 
    SuperscriptBox["A5", "2"]}], "+", 
   RowBox[{"12", " ", "A5", " ", "A6"}], "+", 
   RowBox[{"48", " ", "A5", " ", "A7"}], "+", 
   RowBox[{"12", " ", "A5", " ", "A8"}], "+", 
   RowBox[{"21", " ", 
    SuperscriptBox["A6", "2"]}], "+", 
   RowBox[{"12", " ", "A6", " ", "A7"}], "+", 
   RowBox[{"18", " ", "A6", " ", "A8"}], "+", 
   RowBox[{"48", " ", 
    SuperscriptBox["A7", "2"]}], "+", 
   RowBox[{"12", " ", "A7", " ", "A8"}], "+", 
   RowBox[{"21", " ", 
    SuperscriptBox["A8", "2"]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8283607452677183`*^9, 3.8283607573417377`*^9}, 
   3.828499549813953*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"35e09c2c-00a7-499c-9944-db8c4d64cd34"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "combined", " ", "traceless", " ", "property", " ", "from", 
    " ", "above", " ", "with", " ", "the", " ", "additional", " ", 
    "normalization", " ", 
    RowBox[{"constraint", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A5", "-", "A7", "-", "A8"}],
       "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A8"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A5"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A3"}], "+", "A4", "-", "A6", "-", 
       RowBox[{"2", " ", "A7"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A3", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A4", "+", "A6"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"12", " ", "A1"}], "+", 
       RowBox[{"3", " ", "A2"}], "+", 
       RowBox[{"32", " ", "A3"}], "+", 
       RowBox[{"7", " ", "A4"}], "+", 
       RowBox[{"18", " ", "A5"}], "+", 
       RowBox[{"3", " ", "A6"}], "+", 
       RowBox[{"18", " ", "A7"}], "+", 
       RowBox[{"3", " ", "A8"}]}], "\[Equal]", 
      RowBox[{"-", "5"}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"6", " ", "A1"}], "+", 
       RowBox[{"9", " ", "A2"}], "+", 
       RowBox[{"14", " ", "A3"}], "+", 
       RowBox[{"25", " ", "A4"}], "+", 
       RowBox[{"6", " ", "A5"}], "+", 
       RowBox[{"15", " ", "A6"}], "+", 
       RowBox[{"6", " ", "A7"}], "+", 
       RowBox[{"15", " ", "A8"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"24", " ", 
        SuperscriptBox["A1", "2"]}], "+", 
       RowBox[{"12", " ", "A1", " ", 
        RowBox[{"(", 
         RowBox[{"A2", "+", 
          RowBox[{"4", " ", "A3"}], "+", "A4", "+", 
          RowBox[{"4", " ", "A5"}], "+", "A6", "+", 
          RowBox[{"4", " ", "A7"}], "+", "A8"}], ")"}]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["A2", "2"]}], "+", 
       RowBox[{"6", " ", "A2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "A3"}], "+", 
          RowBox[{"3", " ", "A4"}], "+", 
          RowBox[{"2", " ", "A5"}], "+", 
          RowBox[{"3", " ", "A6"}], "+", 
          RowBox[{"2", " ", "A7"}], "+", 
          RowBox[{"3", " ", "A8"}]}], ")"}]}], "+", 
       RowBox[{"136", " ", 
        SuperscriptBox["A3", "2"]}], "+", 
       RowBox[{"76", " ", "A3", " ", "A4"}], "+", 
       RowBox[{"96", " ", "A3", " ", "A5"}], "+", 
       RowBox[{"12", " ", "A3", " ", "A6"}], "+", 
       RowBox[{"96", " ", "A3", " ", "A7"}], "+", 
       RowBox[{"12", " ", "A3", " ", "A8"}], "+", 
       RowBox[{"49", " ", 
        SuperscriptBox["A4", "2"]}], "+", 
       RowBox[{"12", " ", "A4", " ", "A5"}], "+", 
       RowBox[{"42", " ", "A4", " ", "A6"}], "+", 
       RowBox[{"12", " ", "A4", " ", "A7"}], "+", 
       RowBox[{"42", " ", "A4", " ", "A8"}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["A5", "2"]}], "+", 
       RowBox[{"12", " ", "A5", " ", "A6"}], "+", 
       RowBox[{"48", " ", "A5", " ", "A7"}], "+", 
       RowBox[{"12", " ", "A5", " ", "A8"}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox["A6", "2"]}], "+", 
       RowBox[{"12", " ", "A6", " ", "A7"}], "+", 
       RowBox[{"18", " ", "A6", " ", "A8"}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["A7", "2"]}], "+", 
       RowBox[{"12", " ", "A7", " ", "A8"}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox["A8", "2"]}]}], "\[Equal]", "5"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "A7", 
      ",", "A8"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828360722776339*^9, 3.8283607429696817`*^9}, {
  3.828500642305457*^9, 
  3.828500663686398*^9}},ExpressionUUID->"1d0f0c92-c061-4ed6-acf2-\
c879ae84c0f0"],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "Solve","svars",
    "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
    35,3,21029053522522598765,"Local"},
   "MessageTemplate"], TraditionalForm]], "Message", "MSG",
 CellChangeTimes->{3.8283607600303*^9, 3.828410393215073*^9, 
  3.828499552319187*^9},
 CellLabel->
  "During evaluation of \
In[35]:=",ExpressionUUID->"80aaeee1-58e1-46b6-aa62-6733b4bc00de"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "A3"}], "-", "1"}], ")"}]}]}], ",", 
     RowBox[{"A2", "\[Rule]", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"6", " ", "A3"}]}], ")"}]}]}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "A3"}]}], ",", 
     RowBox[{"A5", "\[Rule]", 
      RowBox[{"-", "A3"}]}], ",", 
     RowBox[{"A6", "\[Rule]", 
      RowBox[{"2", " ", "A3"}]}], ",", 
     RowBox[{"A7", "\[Rule]", 
      RowBox[{"-", "A3"}]}], ",", 
     RowBox[{"A8", "\[Rule]", 
      RowBox[{"2", " ", "A3"}]}]}], "}"}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->{3.828360760056378*^9, 3.828410393250648*^9, 
  3.8284995523433228`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"fd08f0af-7cd9-4a53-9a18-64a32ecd76e9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Ansatz", " ", "with", " ", "only", " ", "X", " ", "and", " ", "not", " ", 
    
    RowBox[{"X2", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P2Try2", "[", 
     RowBox[{"\[Mu]1_", ",", "\[Mu]2_", ",", "\[Nu]1_", ",", "\[Nu]2_"}], 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"A1", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Nu]1"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Nu]2"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{"A2", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"X", "[", 
         RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
        RowBox[{"X", "[", 
         RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], ")"}]}]}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.8281881651109867`*^9, 3.8281881754837923`*^9}, {
  3.828359217440782*^9, 3.828359226990185*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"e2fd3ad4-925d-4729-82a9-1388fc5213d6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "properties", " ", "of", " ", "the", " ", "above", " ", 
    "tensor", " ", "when", " ", "contracting", " ", "with", " ", "the", " ", 
    "objects", " ", "as", " ", 
    RowBox[{"before", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try2", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Mu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try2", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Nu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try2", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P2Try2", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2", ",", "\[Nu]1", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.828188186948106*^9, 3.8281881896897*^9}, {
  3.828188309480391*^9, 3.828188311661968*^9}, {3.828359363458445*^9, 
  3.8283593640798883`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"56c82c5a-ccb6-4f66-8dce-074d3c5512ee"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8281881923329277`*^9, 3.8281883123524437`*^9, 
  3.828359365208254*^9, 3.828499556817268*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"c5bc4574-f178-4041-b1b5-5531a6bcd052"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.8281881923329277`*^9, 3.8281883123524437`*^9, 
  3.828359365208254*^9, 3.8284995568245564`*^9},
 CellLabel->"Out[38]=",ExpressionUUID->"34fe41a4-1d43-494c-b41b-457a024b8022"],

Cell[BoxData[
 FormBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", "A1"}], "+", "A2"}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.8281881923329277`*^9, 3.8281883123524437`*^9, 
  3.828359365208254*^9, 3.828499556829133*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"6efd6ddc-7586-4614-b2a4-d198621a7d29"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"6", " ", "A1"}], "+", 
   RowBox[{"9", " ", "A2"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.8281881923329277`*^9, 3.8281883123524437`*^9, 
  3.828359365208254*^9, 3.82849955689431*^9},
 CellLabel->"Out[40]=",ExpressionUUID->"69d450d3-af97-4caa-9ad6-508d1a37c009"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solving", " ", "the", " ", "system", " ", "of", " ", "equations", " ", 
    "from", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"4", " ", "A1"}], "+", "A2"}], ")"}]}], "\[Equal]", 
      RowBox[{"-", "5"}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"6", " ", "A1"}], "+", 
       RowBox[{"9", " ", "A2"}]}], "\[Equal]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"A1", ",", "A2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.82818346428656*^9, 3.828183464591908*^9}, {
  3.828184628441403*^9, 3.828184629156781*^9}, {3.828188316730199*^9, 
  3.828188332077128*^9}, {3.8283593890655937`*^9, 3.8283593942810497`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"25fd70ba-502b-457b-a7c5-e59db5d13629"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "2"]}]}], ",", 
     RowBox[{"A2", "\[Rule]", 
      FractionBox["1", "3"]}]}], "}"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.828188332464747*^9, 3.828499558799801*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"d5bba94d-89b7-4f45-9f32-6a37274c440e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "obtained", " ", "polarization", " ", "sum", " ", "for", " ", 
     "massive", " ", "spin"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P2", "[", 
     RowBox[{"\[Mu]_", ",", "\[Nu]_", ",", "\[Rho]_", ",", "\[Sigma]_"}], 
     "]"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]", ",", "\[Rho]"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Nu]", ",", "\[Sigma]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Nu]", ",", "\[Rho]"}], "]"}]}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["1", "3"], 
      RowBox[{"X", "[", 
       RowBox[{"\[Mu]", ",", "\[Nu]"}], "]"}], 
      RowBox[{"X", "[", 
       RowBox[{"\[Rho]", ",", "\[Sigma]"}], "]"}]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.828359372244763*^9, 3.8283593861740303`*^9}, {
  3.828499939442368*^9, 3.828499941390168*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"f70ced36-b3c2-4518-b74b-416318bf2da1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Spin-3", "Section",
 CellChangeTimes->{{3.828355290638372*^9, 
  3.8283552978613787`*^9}},ExpressionUUID->"0b9e0b05-02bc-46ae-a46a-\
702227178477"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Permutations", " ", "of", " ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "."}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Perm", "=", 
    RowBox[{"Permutations", "[", 
     RowBox[{"{", 
      RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}]}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.828357794293468*^9, 3.828357808388302*^9}},
 CellLabel->"In[67]:=",ExpressionUUID->"8c38fcec-6291-4f27-b2eb-6e2c3b910c40"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Ansatz", " ", "to", " ", "derive", " ", "the", " ", "polarization", " ", 
     "sum", " ", "for", " ", "a", " ", "massive", " ", "spin"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"particle", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P3Try", "[", 
     RowBox[{
     "\[Mu]1_", ",", "\[Mu]2_", ",", "\[Mu]3_", ",", "\[Nu]1_", ",", 
      "\[Nu]2_", ",", "\[Nu]3_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"A1", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A3", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A4", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A5", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A6", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A7", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A8", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A9", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A10", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A11", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A12", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A13", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A14", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], ")"}]}],
      "+", 
     RowBox[{"A15", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X2", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A16", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X2", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], 
       ")"}]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.828360825831934*^9, 3.828360873319476*^9}, 
   3.8283609325870657`*^9, {3.82836097495569*^9, 3.828361040944175*^9}, {
   3.8283610721836033`*^9, 3.828361205981351*^9}, {3.828501610160893*^9, 
   3.828501623091711*^9}},
 CellLabel->"In[68]:=",ExpressionUUID->"4e334f5b-c935-4c51-80f2-811249b296a0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "properties", " ", "of", " ", "the", " ", "above", " ", 
    "tensor", " ", "when", " ", "contracting", " ", "with", " ", "the", " ", 
    "objects", " ", "as", " ", 
    RowBox[{"before", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Mu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Nu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]3", ",", "\[Nu]3"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.8283561295811977`*^9, 3.8283561485263233`*^9}, {
  3.828356240153294*^9, 3.8283562485475607`*^9}, {3.828357315765493*^9, 
  3.8283573200622272`*^9}, {3.828359759567922*^9, 3.828359760168893*^9}, {
  3.828360808662788*^9, 3.828360811045594*^9}, {3.8283612189666643`*^9, 
  3.828361222833905*^9}, {3.828361322102028*^9, 3.82836132543233*^9}, {
  3.828410623649334*^9, 3.828410627403685*^9}},
 CellLabel->"In[69]:=",ExpressionUUID->"1bf3b2d6-7085-4ad7-82cd-819d615c6f0a"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["M", "4"]], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A4", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A11", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A15", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A3", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A9", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A11", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A15", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A3", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A9", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A11", "+", "A15", "+", "A3", "+", "A9"}], ")"}], " ", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]1",
                    TraditionalForm],
                   TraditionalForm]]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]1",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]2",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]3",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A12", "+", "A16", "+", "A4"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Nu]1",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "A10", "+", "A11", "-", "A12", "+", "A15", "+", "A16", "-", 
                   "A3", "-", "A4", "-", "A9"}], ")"}], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]1",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]2",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A11", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A15", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"2", " ", "A3", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"2", " ", "A4", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"2", " ", "A9", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"6", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"6", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"6", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"6", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A11", "+", "A15", "+", "A3", "+", "A9"}], ")"}], " ", 
              
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]1",
                    TraditionalForm],
                   TraditionalForm]]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]1",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]3",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{"2", " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]3",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A12", "+", "A16", "+", "A4"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Nu]1",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                  "A10", "+", "A11", "-", "A12", "+", "A15", "+", "A16", "-", 
                   "A3", "-", "A4", "-", "A9"}], ")"}], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]1",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]3",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["p",
            TraditionalForm], "_"],
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]2",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A10", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"A4", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "-", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A4", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A4", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A4", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A10", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A11", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A15", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A3", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A4", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"A9", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]1",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A10", "+", "A12", "+", "A16", "+", "A4"}], ")"}], " ", 
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Nu]1",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Nu]3",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "A10", "-", "A11", "-", "A12", "+", "A15", "+", "A16", "-", 
                "A3", "-", "A4", "+", "A9"}], ")"}], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]1",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]3",
                 TraditionalForm],
                TraditionalForm]]}]}], ")"}], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A10", "+", "A12", "+", "A16", "+", "A4"}], ")"}], " ", 
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Nu]1",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Nu]2",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              SuperscriptBox["M", "4"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
               "A10", "-", "A11", "-", "A12", "+", "A15", "+", "A16", "-", 
                "A3", "-", "A4", "+", "A9"}], ")"}], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]1",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]2",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["M", "2"]}]}], ")"}]}], "-", 
          RowBox[{"6", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"3", " ", "A11", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"9", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"3", " ", "A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"3", " ", "A15", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"9", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"3", " ", "A3", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"6", " ", "A4", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"3", " ", "A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"3", " ", "A9", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]1",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828361235191868*^9, 3.828361329429731*^9, {3.8284106182603416`*^9, 
   3.8284106307565727`*^9}, 3.828501637748027*^9},
 CellLabel->"Out[69]=",ExpressionUUID->"32b6f487-ee06-4958-9ce5-044149f7010d"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox["M", "4"]], 
    RowBox[{"2", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A11", "+", "A13", "+", "A15", "+", "A7"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]3",
                    TraditionalForm],
                   TraditionalForm]]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A14", "+", "A16", "+", "A6"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]2",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]2",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A13", "+", "A15", "+", "A5", "+", "A9"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "A10"}], "-", "A11", "+", 
                   RowBox[{"2", " ", "A13"}], "-", 
                   RowBox[{"2", " ", "A14"}], "+", 
                   RowBox[{"2", " ", "A15"}], "+", 
                   RowBox[{"2", " ", "A16"}], "-", "A5", "-", 
                   RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]3",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]2",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]1",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A11", "+", "A13", "+", "A15", "+", "A7"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]3",
                    TraditionalForm],
                   TraditionalForm]]}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A14", "+", "A16", "+", "A6"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]3",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]2",
                 TraditionalForm],
                TraditionalForm]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A13", "+", "A15", "+", "A5", "+", "A9"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  OverscriptBox["g", "_"], 
                  RowBox[{
                   FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                   FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"2", " ", "A10"}], "-", "A11", "+", 
                   RowBox[{"2", " ", "A13"}], "-", 
                   RowBox[{"2", " ", "A14"}], "+", 
                   RowBox[{"2", " ", "A15"}], "+", 
                   RowBox[{"2", " ", "A16"}], "-", "A5", "-", 
                   RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], ")"}], 
                 " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]3",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Nu]3",
                    TraditionalForm],
                   TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Mu]1",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Mu]3",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A14", "+", "A16", "+", "A6"}], ")"}], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Mu]2",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]2",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"A12", "+", "A14", "+", "A16", "+", "A8"}], ")"}],
                     " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]]}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "A10"}], "+", "A12", "-", 
                    RowBox[{"3", " ", "A14"}], "-", 
                    RowBox[{"3", " ", "A16"}], "+", 
                    RowBox[{"2", " ", "A6"}], "+", "A8"}], ")"}], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Mu]1",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Mu]2",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"A10", "+", "A14", "+", "A16", "+", "A6"}], ")"}], 
                 " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]]}], "+", 
                   RowBox[{
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Mu]3",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]}]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}], " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{
                 SuperscriptBox[
                  FormBox[
                   OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                   TraditionalForm], 
                  FormBox[
                   FormBox["\[Mu]3",
                    TraditionalForm],
                   TraditionalForm]], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"A12", "+", "A14", "+", "A16", "+", "A8"}], ")"}],
                     " ", 
                    SuperscriptBox["M", "2"], " ", 
                    SuperscriptBox[
                    OverscriptBox["g", "_"], 
                    RowBox[{
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]}]]}], "-", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "A10"}], "+", "A12", "-", 
                    RowBox[{"3", " ", "A14"}], "-", 
                    RowBox[{"3", " ", "A16"}], "+", 
                    RowBox[{"2", " ", "A6"}], "+", "A8"}], ")"}], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]2",
                    TraditionalForm],
                    TraditionalForm]], " ", 
                    SuperscriptBox[
                    FormBox[
                    OverscriptBox[
                    FormBox["p",
                    TraditionalForm], "_"],
                    TraditionalForm], 
                    FormBox[
                    FormBox["\[Nu]3",
                    TraditionalForm],
                    TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
         ")"}], " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["p",
            TraditionalForm], "_"],
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]1",
           TraditionalForm],
          TraditionalForm]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"2", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "4"]}], "+", 
          RowBox[{"6", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"6", " ", "A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"6", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"6", " ", "A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A11", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A13", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A15", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A3", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A5", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A6", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A9", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A11", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A13", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A15", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A3", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"A5", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A6", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"2", " ", "A9", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"4", " ", "A10", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A12", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"6", " ", "A14", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"6", " ", "A16", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"4", " ", "A6", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"2", " ", "A8", " ", 
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Mu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]2",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A11", "+", "A15", "+", "A3", "+", "A9"}], ")"}], " ", 
              
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Mu]3",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Nu]3",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "A10"}], "+", 
                RowBox[{"2", " ", "A11"}], "-", "A13", "-", 
                RowBox[{"2", " ", "A14"}], "+", 
                RowBox[{"2", " ", "A15"}], "+", 
                RowBox[{"2", " ", "A16"}], "-", "A3", "-", 
                RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], ")"}], " ", 
              
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]3",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]3",
                 TraditionalForm],
                TraditionalForm]]}]}], ")"}], " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            OverscriptBox["g", "_"], 
            RowBox[{
             FormBox[
              FormBox["\[Mu]2",
               TraditionalForm],
              TraditionalForm], 
             FormBox[
              FormBox["\[Nu]3",
               TraditionalForm],
              TraditionalForm]}]], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"A11", "+", "A15", "+", "A3", "+", "A9"}], ")"}], " ", 
              
              SuperscriptBox[
               OverscriptBox["g", "_"], 
               RowBox[{
                FormBox[
                 FormBox["\[Mu]3",
                  TraditionalForm],
                 TraditionalForm], 
                FormBox[
                 FormBox["\[Nu]2",
                  TraditionalForm],
                 TraditionalForm]}]], " ", 
              SuperscriptBox["M", "4"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"2", " ", "A10"}], "+", 
                RowBox[{"2", " ", "A11"}], "-", "A13", "-", 
                RowBox[{"2", " ", "A14"}], "+", 
                RowBox[{"2", " ", "A15"}], "+", 
                RowBox[{"2", " ", "A16"}], "-", "A3", "-", 
                RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], ")"}], " ", 
              
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Mu]3",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox[
               FormBox[
                OverscriptBox[
                 FormBox["p",
                  TraditionalForm], "_"],
                TraditionalForm], 
               FormBox[
                FormBox["\[Nu]2",
                 TraditionalForm],
                TraditionalForm]], " ", 
              SuperscriptBox["M", "2"]}]}], ")"}]}], "-", 
          RowBox[{"12", " ", "A10", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"4", " ", "A11", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"6", " ", "A12", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"4", " ", "A13", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"18", " ", "A14", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"6", " ", "A15", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"18", " ", "A16", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A3", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A5", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"12", " ", "A6", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"2", " ", "A7", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "+", 
          RowBox[{"6", " ", "A8", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}], "-", 
          RowBox[{"4", " ", "A9", " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Mu]3",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]2",
              TraditionalForm],
             TraditionalForm]], " ", 
           SuperscriptBox[
            FormBox[
             OverscriptBox[
              FormBox["p",
               TraditionalForm], "_"],
             TraditionalForm], 
            FormBox[
             FormBox["\[Nu]3",
              TraditionalForm],
             TraditionalForm]]}]}], ")"}]}]}], ")"}]}]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828361235191868*^9, 3.828361329429731*^9, {3.8284106182603416`*^9, 
   3.8284106307565727`*^9}, 3.828501640441639*^9},
 CellLabel->"Out[70]=",ExpressionUUID->"e44ec2dc-4bb8-4d33-a512-9ad73cd6facc"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"10", " ", "A1"}], "+", 
     RowBox[{"27", " ", "A10"}], "+", 
     RowBox[{"22", " ", "A11"}], "+", 
     RowBox[{"21", " ", "A12"}], "+", 
     RowBox[{"22", " ", "A13"}], "+", 
     RowBox[{"21", " ", "A14"}], "+", 
     RowBox[{"42", " ", "A15"}], "+", 
     RowBox[{"57", " ", "A16"}], "+", 
     RowBox[{"15", " ", "A2"}], "+", 
     RowBox[{"14", " ", "A3"}], "+", 
     RowBox[{"15", " ", "A4"}], "+", 
     RowBox[{"14", " ", "A5"}], "+", 
     RowBox[{"15", " ", "A6"}], "+", 
     RowBox[{"14", " ", "A7"}], "+", 
     RowBox[{"21", " ", "A8"}], "+", 
     RowBox[{"22", " ", "A9"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828361235191868*^9, 3.828361329429731*^9, {3.8284106182603416`*^9, 
   3.8284106307565727`*^9}, 3.828501640813534*^9},
 CellLabel->"Out[71]=",ExpressionUUID->"275aeff2-020a-46db-979e-149a9b7270b3"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2", " ", 
     SuperscriptBox[
      OverscriptBox["g", "_"], 
      RowBox[{
       FormBox[
        FormBox["\[Mu]3",
         TraditionalForm],
        TraditionalForm], 
       FormBox[
        FormBox["\[Nu]3",
         TraditionalForm],
        TraditionalForm]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"5", " ", "A1"}], "+", 
       RowBox[{"49", " ", "A10"}], "+", 
       RowBox[{"5", " ", "A11"}], "+", 
       RowBox[{"35", " ", "A12"}], "+", 
       RowBox[{"5", " ", "A13"}], "+", 
       RowBox[{"35", " ", "A14"}], "+", 
       RowBox[{"9", " ", "A15"}], "+", 
       RowBox[{"49", " ", "A16"}], "+", 
       RowBox[{"25", " ", "A2"}], "+", 
       RowBox[{"5", " ", "A3"}], "+", 
       RowBox[{"35", " ", "A4"}], "+", 
       RowBox[{"5", " ", "A5"}], "+", 
       RowBox[{"35", " ", "A6"}], "+", 
       RowBox[{"5", " ", "A7"}], "+", 
       RowBox[{"25", " ", "A8"}], "+", 
       RowBox[{"9", " ", "A9"}]}], ")"}]}]}], "-", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Mu]3",
        TraditionalForm],
       TraditionalForm]], " ", 
     SuperscriptBox[
      FormBox[
       OverscriptBox[
        FormBox["p",
         TraditionalForm], "_"],
       TraditionalForm], 
      FormBox[
       FormBox["\[Nu]3",
        TraditionalForm],
       TraditionalForm]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"5", " ", "A1"}]}], "-", 
       RowBox[{"49", " ", "A10"}], "+", "A11", "+", 
       RowBox[{"19", " ", "A12"}], "+", "A13", "+", 
       RowBox[{"19", " ", "A14"}], "+", 
       RowBox[{"21", " ", "A15"}], "+", 
       RowBox[{"113", " ", "A16"}], "-", 
       RowBox[{"25", " ", "A2"}], "-", 
       RowBox[{"5", " ", "A3"}], "-", 
       RowBox[{"35", " ", "A4"}], "-", 
       RowBox[{"5", " ", "A5"}], "-", 
       RowBox[{"35", " ", "A6"}], "+", "A7", "-", 
       RowBox[{"7", " ", "A8"}], "-", 
       RowBox[{"9", " ", "A9"}]}], ")"}]}], 
    SuperscriptBox["M", "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828361235191868*^9, 3.828361329429731*^9, {3.8284106182603416`*^9, 
   3.8284106307565727`*^9}, 3.828501641240737*^9},
 CellLabel->"Out[72]=",ExpressionUUID->"a70d96eb-3410-40b0-a335-57b96ea874c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solving", " ", "the", " ", "system", " ", "of", " ", "equations", " ", 
    "from", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"A10", " ", "\[Equal]", "0"}], "&&", 
     RowBox[{"A12", "\[Equal]", "0"}], "&&", 
     RowBox[{"A16", "\[Equal]", "0"}], "&&", 
     RowBox[{"A4", "\[Equal]", "0"}], "&&", 
     RowBox[{"A14", "\[Equal]", "0"}], "&&", 
     RowBox[{"A8", "\[Equal]", "0"}], "&&", 
     RowBox[{"A11", "\[Equal]", "0"}], "&&", 
     RowBox[{"A15", "\[Equal]", "0"}], "&&", 
     RowBox[{"A3", "\[Equal]", "0"}], "&&", 
     RowBox[{"A9", "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A11", "+", "A15", "+", "A3", "+", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A10", "+", "A12", "+", "A16", "+", "A4"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "A10", "+", "A11", "-", "A12", "+", "A15", "+", "A16", "-", "A3", "-", 
       "A4", "-", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
      "A10", "-", "A11", "-", "A12", "+", "A15", "+", "A16", "-", "A3", "-", 
       "A4", "+", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A11", "+", "A13", "+", "A15", "+", "A7"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A10", "+", "A14", "+", "A16", "+", "A6"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A13", "+", "A15", "+", "A5", "+", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A10"}], "-", "A11", "+", 
       RowBox[{"2", " ", "A13"}], "-", 
       RowBox[{"2", " ", "A14"}], "+", 
       RowBox[{"2", " ", "A15"}], "+", 
       RowBox[{"2", " ", "A16"}], "-", "A5", "-", 
       RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{"A11", "+", "A13", "+", "A15", "+", "A7"}], "\[Equal]", "0"}], 
     "&&", 
     RowBox[{
      RowBox[{"A12", "+", "A14", "+", "A16", "+", "A8"}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A10"}], "+", "A12", "-", 
       RowBox[{"3", " ", "A14"}], "-", 
       RowBox[{"3", " ", "A16"}], "+", 
       RowBox[{"2", " ", "A6"}], "+", "A8"}], "\[Equal]", "0"}], "&&", 
     RowBox[{"A13", "\[Equal]", "0"}], "&&", 
     RowBox[{"A5", "\[Equal]", "0"}], "&&", 
     RowBox[{"A6", "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"2", " ", "A10"}], "+", 
       RowBox[{"2", " ", "A11"}], "-", "A13", "-", 
       RowBox[{"2", " ", "A14"}], "+", 
       RowBox[{"2", " ", "A15"}], "+", 
       RowBox[{"2", " ", "A16"}], "-", "A3", "-", 
       RowBox[{"2", " ", "A6"}], "-", "A7", "-", "A9"}], "\[Equal]", "0"}], "&&", 
     RowBox[{"A7", "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", " ", "A1"}], "+", 
         RowBox[{"27", " ", "A10"}], "+", 
         RowBox[{"22", " ", "A11"}], "+", 
         RowBox[{"21", " ", "A12"}], "+", 
         RowBox[{"22", " ", "A13"}], "+", 
         RowBox[{"21", " ", "A14"}], "+", 
         RowBox[{"42", " ", "A15"}], "+", 
         RowBox[{"57", " ", "A16"}], "+", 
         RowBox[{"15", " ", "A2"}], "+", 
         RowBox[{"14", " ", "A3"}], "+", 
         RowBox[{"15", " ", "A4"}], "+", 
         RowBox[{"14", " ", "A5"}], "+", 
         RowBox[{"15", " ", "A6"}], "+", 
         RowBox[{"14", " ", "A7"}], "+", 
         RowBox[{"21", " ", "A8"}], "+", 
         RowBox[{"22", " ", "A9"}]}], ")"}]}], "\[Equal]", 
      RowBox[{"-", "7"}]}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{"5", " ", "A1"}], "+", 
       RowBox[{"49", " ", "A10"}], "+", 
       RowBox[{"5", " ", "A11"}], "+", 
       RowBox[{"35", " ", "A12"}], "+", 
       RowBox[{"5", " ", "A13"}], "+", 
       RowBox[{"35", " ", "A14"}], "+", 
       RowBox[{"9", " ", "A15"}], "+", 
       RowBox[{"49", " ", "A16"}], "+", 
       RowBox[{"25", " ", "A2"}], "+", 
       RowBox[{"5", " ", "A3"}], "+", 
       RowBox[{"35", " ", "A4"}], "+", 
       RowBox[{"5", " ", "A5"}], "+", 
       RowBox[{"35", " ", "A6"}], "+", 
       RowBox[{"5", " ", "A7"}], "+", 
       RowBox[{"25", " ", "A8"}], "+", 
       RowBox[{"9", " ", "A9"}]}], "\[Equal]", "0"}], "&&", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "5"}], " ", "A1"}], "-", 
       RowBox[{"49", " ", "A10"}], "+", "A11", "+", 
       RowBox[{"19", " ", "A12"}], "+", "A13", "+", 
       RowBox[{"19", " ", "A14"}], "+", 
       RowBox[{"21", " ", "A15"}], "+", 
       RowBox[{"113", " ", "A16"}], "-", 
       RowBox[{"25", " ", "A2"}], "-", 
       RowBox[{"5", " ", "A3"}], "-", 
       RowBox[{"35", " ", "A4"}], "-", 
       RowBox[{"5", " ", "A5"}], "-", 
       RowBox[{"35", " ", "A6"}], "+", "A7", "-", 
       RowBox[{"7", " ", "A8"}], "-", 
       RowBox[{"9", " ", "A9"}]}], "\[Equal]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{
     "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "A7", 
      ",", "A8", ",", "A9", ",", "A10", ",", "A11", ",", "A12", ",", "A13", 
      ",", "A14", ",", "A15", ",", "A16"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828501660109045*^9, 3.828501778404253*^9}, {
   3.828501847723475*^9, 3.828501890914461*^9}, 3.828501927704166*^9, {
   3.828502120813702*^9, 3.828502158275948*^9}, {3.828502265727944*^9, 
   3.828502333561343*^9}, {3.828502412092618*^9, 3.8285024233722897`*^9}, {
   3.828502526323359*^9, 3.828502528379561*^9}, {3.8285025651161747`*^9, 
   3.828502592560601*^9}, {3.82850272218095*^9, 3.8285027240558023`*^9}, {
   3.8285028330816174`*^9, 3.828502837326661*^9}, {3.8285029625345383`*^9, 
   3.828502990568063*^9}},
 CellLabel->"In[73]:=",ExpressionUUID->"a18dd21f-409d-4e63-b531-7bede0cdc1a4"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{"A2", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "30"]}]}], ",", 
     RowBox[{"A3", "\[Rule]", "0"}], ",", 
     RowBox[{"A4", "\[Rule]", "0"}], ",", 
     RowBox[{"A5", "\[Rule]", "0"}], ",", 
     RowBox[{"A6", "\[Rule]", "0"}], ",", 
     RowBox[{"A7", "\[Rule]", "0"}], ",", 
     RowBox[{"A8", "\[Rule]", "0"}], ",", 
     RowBox[{"A9", "\[Rule]", "0"}], ",", 
     RowBox[{"A10", "\[Rule]", "0"}], ",", 
     RowBox[{"A11", "\[Rule]", "0"}], ",", 
     RowBox[{"A12", "\[Rule]", "0"}], ",", 
     RowBox[{"A13", "\[Rule]", "0"}], ",", 
     RowBox[{"A14", "\[Rule]", "0"}], ",", 
     RowBox[{"A15", "\[Rule]", "0"}], ",", 
     RowBox[{"A16", "\[Rule]", "0"}]}], "}"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.828502991264292*^9},
 CellLabel->"Out[73]=",ExpressionUUID->"aec0ebcd-6e87-4723-af92-65259b772eae"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Ansatz", " ", "with", " ", "only", " ", "X", " ", "and", " ", "not", " ", 
    
    RowBox[{"X2", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P3Try2", "[", 
     RowBox[{
     "\[Mu]1_", ",", "\[Mu]2_", ",", "\[Mu]3_", ",", "\[Nu]1_", ",", 
      "\[Nu]2_", ",", "\[Nu]3_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"A1", "*", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{"Perm", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], "+", 
     RowBox[{"A2", "*", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]3", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}], "+", 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
           RowBox[{"X", "[", 
            RowBox[{"\[Mu]1", ",", 
             RowBox[{"Perm", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"Length", "[", "Perm", "]"}]}], "}"}]}], "]"}]}], 
       ")"}]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.828281728041811*^9, 3.8282817448641987`*^9}, {
   3.8283553156071043`*^9, 3.828355344096199*^9}, {3.828355676070471*^9, 
   3.828355707475752*^9}, {3.82835584407519*^9, 3.8283559866397953`*^9}, {
   3.8283560594111023`*^9, 3.828356096262925*^9}, {3.828356450739378*^9, 
   3.828356453196268*^9}, {3.828356581983233*^9, 3.828356584585359*^9}, {
   3.828359406469348*^9, 3.8283594089117193`*^9}, {3.82835951232788*^9, 
   3.828359610226383*^9}, {3.828359688448011*^9, 3.82835970797071*^9}, 
   3.8283597490441847`*^9, {3.828360801645512*^9, 3.828360807201365*^9}},
 CellLabel->
  "In[513]:=",ExpressionUUID->"828f25c2-3de1-41ef-8758-07b69689fa29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "properties", " ", "of", " ", "the", " ", "above", " ", 
    "tensor", " ", "when", " ", "contracting", " ", "with", " ", "the", " ", 
    "objects", " ", "as", " ", 
    RowBox[{"before", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try2", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Mu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try2", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"FV", "[", 
       RowBox[{"p", ",", "\[Nu]1"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try2", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Nu]1"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]2", ",", "\[Nu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]3", ",", "\[Nu]3"}], "]"}]}], "]"}], "//", "Simplify"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Contract", "[", 
     RowBox[{
      RowBox[{"P3Try2", "[", 
       RowBox[{
       "\[Mu]1", ",", "\[Mu]2", ",", "\[Mu]3", ",", "\[Nu]1", ",", "\[Nu]2", 
        ",", "\[Nu]3"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
      RowBox[{"MT", "[", 
       RowBox[{"\[Nu]1", ",", "\[Nu]2"}], "]"}]}], "]"}], "//", 
    "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.8283561295811977`*^9, 3.8283561485263233`*^9}, {
  3.828356240153294*^9, 3.8283562485475607`*^9}, {3.828357315765493*^9, 
  3.8283573200622272`*^9}, {3.828359759567922*^9, 3.828359760168893*^9}, {
  3.828360808662788*^9, 3.828360811045594*^9}},
 CellLabel->
  "In[514]:=",ExpressionUUID->"0987484d-584a-464b-99a0-997186b19150"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.828356298919117*^9, 3.828356454841178*^9, 
  3.8283570579142923`*^9, 3.828357320538436*^9, 3.8283573654802513`*^9, 
  3.828357992397068*^9, 3.8283594226210318`*^9, 3.828359614379628*^9, 
  3.828359710458709*^9, 3.8283597605796137`*^9, 3.8283608144383287`*^9, 
  3.828411721177361*^9},
 CellLabel->
  "Out[514]=",ExpressionUUID->"11e16d8f-78d6-4a9d-8579-3d9c2d437a97"],

Cell[BoxData[
 FormBox["0", TraditionalForm]], "Output",
 CellChangeTimes->{3.828356298919117*^9, 3.828356454841178*^9, 
  3.8283570579142923`*^9, 3.828357320538436*^9, 3.8283573654802513`*^9, 
  3.828357992397068*^9, 3.8283594226210318`*^9, 3.828359614379628*^9, 
  3.828359710458709*^9, 3.8283597605796137`*^9, 3.8283608144383287`*^9, 
  3.8284117212761393`*^9},
 CellLabel->
  "Out[515]=",ExpressionUUID->"c2e767af-886b-478c-9df4-8fd7ace21903"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", "30"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "A1"}], "+", 
     RowBox[{"3", " ", "A2"}]}], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.828356298919117*^9, 3.828356454841178*^9, 
  3.8283570579142923`*^9, 3.828357320538436*^9, 3.8283573654802513`*^9, 
  3.828357992397068*^9, 3.8283594226210318`*^9, 3.828359614379628*^9, 
  3.828359710458709*^9, 3.8283597605796137`*^9, 3.8283608144383287`*^9, 
  3.828411721347467*^9},
 CellLabel->
  "Out[516]=",ExpressionUUID->"43396403-177e-482a-b675-ea9289df3006"],

Cell[BoxData[
 FormBox[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"10", " ", 
     RowBox[{"(", 
      RowBox[{"A1", "+", 
       RowBox[{"5", " ", "A2"}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox[
         OverscriptBox["g", "_"], 
         RowBox[{
          FormBox[
           FormBox["\[Mu]3",
            TraditionalForm],
           TraditionalForm], 
          FormBox[
           FormBox["\[Nu]3",
            TraditionalForm],
           TraditionalForm]}]]}], "-", 
       RowBox[{
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["p",
            TraditionalForm], "_"],
          TraditionalForm], 
         FormBox[
          FormBox["\[Mu]3",
           TraditionalForm],
          TraditionalForm]], " ", 
        SuperscriptBox[
         FormBox[
          OverscriptBox[
           FormBox["p",
            TraditionalForm], "_"],
          TraditionalForm], 
         FormBox[
          FormBox["\[Nu]3",
           TraditionalForm],
          TraditionalForm]]}]}], ")"}]}], 
    SuperscriptBox["M", "2"]]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.828356298919117*^9, 3.828356454841178*^9, 
  3.8283570579142923`*^9, 3.828357320538436*^9, 3.8283573654802513`*^9, 
  3.828357992397068*^9, 3.8283594226210318`*^9, 3.828359614379628*^9, 
  3.828359710458709*^9, 3.8283597605796137`*^9, 3.8283608144383287`*^9, 
  3.828411721414178*^9},
 CellLabel->
  "Out[517]=",ExpressionUUID->"8b367c05-2727-42c4-8c2f-4de7f4ca094a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solving", " ", "the", " ", "system", " ", "of", " ", "equations", " ", 
    "from", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "30"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "A1"}], "+", 
         RowBox[{"3", " ", "A2"}]}], ")"}]}], "\[Equal]", 
      RowBox[{"-", "7"}]}], "&&", 
     RowBox[{
      RowBox[{"A1", "+", 
       RowBox[{"5", " ", "A2"}]}], "\[Equal]", "0"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"A1", ",", "A2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.828356463875599*^9, 3.82835648747908*^9}, 
   3.828357328643648*^9, {3.8283579991185503`*^9, 3.828358005612545*^9}, {
   3.828359029079568*^9, 3.82835905283405*^9}, {3.82835908327388*^9, 
   3.82835911155089*^9}, {3.828359190525736*^9, 3.8283591930940247`*^9}, {
   3.8283598116033907`*^9, 3.828359812208531*^9}},
 CellLabel->
  "In[518]:=",ExpressionUUID->"38900b81-347b-4e77-ae90-6e6b859a6893"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", 
      FractionBox["1", "6"]}], ",", 
     RowBox[{"A2", "\[Rule]", 
      RowBox[{"-", 
       FractionBox["1", "30"]}]}]}], "}"}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->{
  3.828356488130199*^9, 3.82835736907765*^9, 3.828358006744954*^9, {
   3.8283590298103848`*^9, 3.8283590535003653`*^9}, {3.828359084623301*^9, 
   3.828359111893824*^9}, 3.828359193457127*^9, 3.82835977487668*^9, 
   3.828411722949106*^9},
 CellLabel->
  "Out[518]=",ExpressionUUID->"23107055-cdc9-4ed7-ae1b-ce349a314d8c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "obtained", " ", "polarization", " ", "sum", " ", "for", " ", 
     "massive", " ", "spin"}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P3", "[", 
     RowBox[{
     "\[Mu]1_", ",", "\[Mu]2_", ",", "\[Mu]3_", ",", "\[Nu]1_", ",", 
      "\[Nu]2_", ",", "\[Nu]3_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Permutations", "[", 
            RowBox[{"{", 
             RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
           "]"}]}], "}"}]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "30"], 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Mu]2"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]3", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Permutations", "[", 
            RowBox[{"{", 
             RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
           "]"}]}], "}"}]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "30"], 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", "\[Mu]3"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Permutations", "[", 
            RowBox[{"{", 
             RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
           "]"}]}], "}"}]}], "]"}]}], "-", 
     RowBox[{
      FractionBox["1", "30"], 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]1", ",", "\[Mu]3"}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{"\[Mu]2", ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "2"}], "]"}], "]"}]}], "]"}], 
         RowBox[{"X", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
           RowBox[{
            RowBox[{"Permutations", "[", 
             RowBox[{"{", 
              RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
            "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "3"}], "]"}], "]"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"Permutations", "[", 
            RowBox[{"{", 
             RowBox[{"\[Nu]1", ",", "\[Nu]2", ",", "\[Nu]3"}], "}"}], "]"}], 
           "]"}]}], "}"}]}], "]"}]}]}]}], ";"}]}]], "Input",
 CellChangeTimes->{
  3.828281725491543*^9, 3.828357507775099*^9, {3.828357538467105*^9, 
   3.828357539553048*^9}, {3.8283598044928207`*^9, 3.828359805924837*^9}},
 CellLabel->
  "In[519]:=",ExpressionUUID->"f93f3caa-9246-487c-8afa-6d4a8c1e342b"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1066, 705},
WindowMargins->{{97, Automatic}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 267, 6, 159, "Title",ExpressionUUID->"d1dd134f-0d78-4c9c-b581-c1d015c5b93d"],
Cell[850, 30, 1359, 37, 105, "Input",ExpressionUUID->"4a797638-e151-4e1d-99e2-1f17aa270ff5"],
Cell[CellGroupData[{
Cell[2234, 71, 260, 6, 63, "Input",ExpressionUUID->"1e38a4db-e71d-42a2-8f20-090887fbee0f"],
Cell[CellGroupData[{
Cell[2519, 81, 2489, 67, 30, "Print",ExpressionUUID->"2199b663-28dd-4d60-874f-1133c76f2147"],
Cell[5011, 150, 1229, 30, 30, "Print",ExpressionUUID->"0ac933a5-cb85-4894-969c-4bc3bd9dcc3a"],
Cell[6243, 182, 1235, 33, 30, "Print",ExpressionUUID->"11ca9796-05a2-4b76-9e47-c4f1abf0bf36"],
Cell[7481, 217, 387, 8, 27, "Print",ExpressionUUID->"bf16bbf3-f896-46b9-bd76-c47c476f6519"],
Cell[7871, 227, 388, 8, 27, "Print",ExpressionUUID->"8c7c50ca-58e0-4e1b-b975-3e52477d6c63"],
Cell[8262, 237, 375, 8, 27, "Print",ExpressionUUID->"f6229a3a-fae8-4dea-86a8-619b04561292"]
}, Open  ]]
}, Open  ]],
Cell[8664, 249, 552, 16, 63, "Input",ExpressionUUID->"32736918-3162-4a93-9b91-7ee8371f6d14"],
Cell[CellGroupData[{
Cell[9241, 269, 155, 3, 69, "Section",ExpressionUUID->"c25e2ea8-de20-412f-b4c3-ab35b12aa7fb"],
Cell[CellGroupData[{
Cell[9421, 276, 2649, 73, 149, "Input",ExpressionUUID->"25479a54-80d5-4a2c-bb26-ee92d294c9b5"],
Cell[12073, 351, 703, 21, 47, "Output",ExpressionUUID->"281bd23c-47a2-4cfd-90ea-0f7ceb2c530c"],
Cell[12779, 374, 469, 10, 42, "Output",ExpressionUUID->"8a531590-1230-4bb0-8dad-08476465eebb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13285, 389, 679, 20, 65, "Input",ExpressionUUID->"6fe1548c-870a-4a30-ad49-d055daceba75"],
Cell[13967, 411, 415, 12, 59, "Output",ExpressionUUID->"821049c6-2b29-4cb1-9b41-bed85b6f7f7a"]
}, Open  ]],
Cell[14397, 426, 2686, 65, 183, "Input",ExpressionUUID->"bf952724-57e9-48dc-9e5e-ff79b194e044"],
Cell[CellGroupData[{
Cell[17108, 495, 3828, 104, 298, "Input",ExpressionUUID->"c3b7eedb-2e57-420b-90ff-49a7f358b92e"],
Cell[20939, 601, 402, 7, 37, "Output",ExpressionUUID->"e66f30cd-9dd8-4378-8953-635f2a206fb5"],
Cell[21344, 610, 418, 8, 37, "Output",ExpressionUUID->"19d6e099-43b6-4f98-854d-a86946c9d165"],
Cell[21765, 620, 400, 7, 37, "Output",ExpressionUUID->"f7ea0151-9161-4ae2-8110-4af482563ec2"],
Cell[22168, 629, 647, 19, 39, "Output",ExpressionUUID->"17b9bc47-4a00-486c-b2cf-53720150166e"],
Cell[22818, 650, 418, 8, 37, "Output",ExpressionUUID->"b5ddc06a-bd9e-46a1-81b2-8f8cae6a9ea5"],
Cell[23239, 660, 400, 7, 37, "Output",ExpressionUUID->"38cda6b5-bbfc-4fb3-984f-35c3ab5b2d55"],
Cell[23642, 669, 400, 7, 37, "Output",ExpressionUUID->"00284538-ab6d-44b9-b3e9-79596db98281"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24091, 682, 153, 3, 69, "Section",ExpressionUUID->"0de2768d-c289-47fd-bb45-216431be29fa"],
Cell[24247, 687, 3622, 101, 126, "Input",ExpressionUUID->"4f967f65-2973-45ff-b24b-9497872b6753"],
Cell[CellGroupData[{
Cell[27894, 792, 4453, 106, 279, "Input",ExpressionUUID->"869c43cd-eb24-48f7-9750-7219fb8789a1"],
Cell[32350, 900, 3388, 115, 65, "Output",ExpressionUUID->"fc9b2e55-26dc-45e8-ad70-690b631abaeb"],
Cell[35741, 1017, 3399, 115, 65, "Output",ExpressionUUID->"c3188ed6-0b62-478c-8164-2179e3cbec0c"],
Cell[39143, 1134, 829, 18, 37, "Output",ExpressionUUID->"df36b9b7-adff-4843-a990-e32bdb95420f"],
Cell[39975, 1154, 2053, 65, 62, "Output",ExpressionUUID->"de0e3bce-5a62-4bac-96b5-bb7da98d8922"],
Cell[42031, 1221, 2051, 65, 62, "Output",ExpressionUUID->"e322844a-72d2-4493-a9b0-6f390ed05f3d"],
Cell[44085, 1288, 831, 18, 37, "Output",ExpressionUUID->"ab23a2ec-e90c-42ab-b379-974139529402"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44953, 1311, 3204, 86, 147, "Input",ExpressionUUID->"4451aa56-da71-4220-af09-4980324f68a6"],
Cell[48160, 1399, 385, 10, 24, "Message",ExpressionUUID->"7a3afabe-92ea-413c-ba52-e4cce478c5b8"],
Cell[48548, 1411, 1038, 33, 57, "Output",ExpressionUUID->"2bf9a024-c2ea-4c96-ae0d-6bac44575ae3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49623, 1449, 2703, 67, 105, "Input",ExpressionUUID->"1ad7f87a-8fa1-475d-ad38-f39947d6b38b"],
Cell[52329, 1518, 482, 11, 24, "Message",ExpressionUUID->"dfb7f152-3f09-4b72-a107-dd32499ad33d"],
Cell[52814, 1531, 1334, 38, 57, "Output",ExpressionUUID->"051f8341-a782-41ea-8ab9-3bbf3e40dee2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54185, 1574, 884, 23, 63, "Input",ExpressionUUID->"9d17d561-d522-4502-94ad-55081abd3a98"],
Cell[55072, 1599, 1974, 51, 85, "Output",ExpressionUUID->"35e09c2c-00a7-499c-9944-db8c4d64cd34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57083, 1655, 4146, 107, 172, "Input",ExpressionUUID->"1d0f0c92-c061-4ed6-acf2-c879ae84c0f0"],
Cell[61232, 1764, 430, 11, 24, "Message",ExpressionUUID->"80aaeee1-58e1-46b6-aa62-6733b4bc00de"],
Cell[61665, 1777, 1016, 31, 57, "Output",ExpressionUUID->"fd08f0af-7cd9-4a53-9a18-64a32ecd76e9"]
}, Open  ]],
Cell[62696, 1811, 1251, 36, 63, "Input",ExpressionUUID->"e2fd3ad4-925d-4729-82a9-1388fc5213d6"],
Cell[CellGroupData[{
Cell[63972, 1851, 1932, 48, 168, "Input",ExpressionUUID->"56c82c5a-ccb6-4f66-8dce-074d3c5512ee"],
Cell[65907, 1901, 250, 4, 37, "Output",ExpressionUUID->"c5bc4574-f178-4041-b1b5-5531a6bcd052"],
Cell[66160, 1907, 252, 4, 37, "Output",ExpressionUUID->"34fe41a4-1d43-494c-b41b-457a024b8022"],
Cell[66415, 1913, 353, 9, 37, "Output",ExpressionUUID->"6efd6ddc-7586-4614-b2a4-d198621a7d29"],
Cell[66771, 1924, 322, 7, 37, "Output",ExpressionUUID->"69d450d3-af97-4caa-9ad6-508d1a37c009"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67130, 1936, 950, 25, 63, "Input",ExpressionUUID->"25fd70ba-502b-457b-a7c5-e59db5d13629"],
Cell[68083, 1963, 410, 11, 57, "Output",ExpressionUUID->"d5bba94d-89b7-4f45-9f32-6a37274c440e"]
}, Open  ]],
Cell[68508, 1977, 1336, 38, 80, "Input",ExpressionUUID->"f70ced36-b3c2-4518-b74b-416318bf2da1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69881, 2020, 153, 3, 69, "Section",ExpressionUUID->"0b9e0b05-02bc-46ae-a46a-702227178477"],
Cell[70037, 2025, 563, 15, 63, "Input",ExpressionUUID->"8c38fcec-6291-4f27-b2eb-6e2c3b910c40"],
Cell[70603, 2042, 26690, 732, 735, "Input",ExpressionUUID->"4e334f5b-c935-4c51-80f2-811249b296a0"],
Cell[CellGroupData[{
Cell[97318, 2778, 2440, 61, 168, "Input",ExpressionUUID->"1bf3b2d6-7085-4ad7-82cd-819d615c6f0a"],
Cell[99761, 2841, 94665, 3062, 473, "Output",ExpressionUUID->"32b6f487-ee06-4958-9ce5-044149f7010d"],
Cell[194429, 5905, 72498, 2271, 467, "Output",ExpressionUUID->"e44ec2dc-4bb8-4d33-a512-9ad73cd6facc"],
Cell[266930, 8178, 964, 25, 37, "Output",ExpressionUUID->"275aeff2-020a-46db-979e-149a9b7270b3"],
Cell[267897, 8205, 2443, 76, 84, "Output",ExpressionUUID->"a70d96eb-3410-40b0-a335-57b96ea874c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[270377, 8286, 5852, 138, 252, "Input",ExpressionUUID->"a18dd21f-409d-4e63-b531-7bede0cdc1a4"],
Cell[276232, 8426, 1001, 26, 57, "Output",ExpressionUUID->"aec0ebcd-6e87-4723-af92-65259b772eae"]
}, Open  ]],
Cell[277248, 8455, 4312, 112, 147, "Input",ExpressionUUID->"828f25c2-3de1-41ef-8758-07b69689fa29"],
Cell[CellGroupData[{
Cell[281585, 8571, 2326, 60, 189, "Input",ExpressionUUID->"0987484d-584a-464b-99a0-997186b19150"],
Cell[283914, 8633, 445, 8, 37, "Output",ExpressionUUID->"11e16d8f-78d6-4a9d-8579-3d9c2d437a97"],
Cell[284362, 8643, 447, 8, 37, "Output",ExpressionUUID->"c2e767af-886b-478c-9df4-8fd7ace21903"],
Cell[284812, 8653, 591, 14, 37, "Output",ExpressionUUID->"43396403-177e-482a-b675-ea9289df3006"],
Cell[285406, 8669, 1572, 51, 63, "Output",ExpressionUUID->"8b367c05-2727-42c4-8c2f-4de7f4ca094a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287015, 8725, 1103, 29, 63, "Input",ExpressionUUID->"38900b81-347b-4e77-ae90-6e6b859a6893"],
Cell[288121, 8756, 614, 17, 57, "Output",ExpressionUUID->"23107055-cdc9-4ed7-ae1b-ce349a314d8c"]
}, Open  ]],
Cell[288750, 8776, 6352, 176, 349, "Input",ExpressionUUID->"f93f3caa-9246-487c-8afa-6d4a8c1e342b"]
}, Open  ]]
}, Open  ]]
}
]
*)

